@@ -25,17 +25,27 @@ class DensityProblem(object):
 
     """
 
-    def __init__(self, X, y, domain=None):
+    def __init__(self, X, y, domain=None, weights=None):
         self.X = X
         if y.ndim == 1:
             y = y.reshape(-1, 1)
         self.y = y
         self.domain = domain
+        self._weights = weights
+        self._r = None
         self._up = None
         self._in = None
         self._pr = None
         self._ob = None
 
+    @property
+    def _n_features(self):
+        return self.y.shape[1]
+
+    @property
+    def _n_samples(self):
+        return self.y.shape[0]
+
     def set_observed(self, distribution=dist.norm()):
         self._ob = distribution.pdf(self.y).prod(axis=1)
 
@@ -47,17 +57,25 @@ class DensityProblem(object):
                 distribution = dist.uniform(loc=mn, scale=mx - mn)
             else:
                 distribution = dist.norm()
+
         initial_dist = distribution
         self._in = initial_dist.pdf(self.X).prod(axis=1)
         self._up = None
         self._pr = None
 
     def set_predicted(self, distribution=None, **kwargs):
+        if "weights" not in kwargs:
+            kwargs["weights"] = self._weights
+        else:
+            self._weights = kwargs["weights"]
+
         if distribution is None:
+            # Reweight kde of predicted by weights from previous iteration if present
             distribution = gkde(self.y.T, **kwargs)
             pred_pdf = distribution.pdf(self.y.T).T
         else:
             pred_pdf = distribution.pdf(self.y, **kwargs)
+
         self._pr = pred_pdf
         self._up = None
 
@@ -70,7 +88,16 @@ class DensityProblem(object):
         if self._ob is None:
             self.set_observed()
 
-        up_pdf = np.divide(np.multiply(self._in, self._ob), self._pr)
+        # Store ratio of observed/predicted
+        # e.g. to comptue E(r) and to pass on to future iterations
+        self._r = np.divide(self._ob, self._pr)
+
+        # If present, multiply by weights (e.g. from a previous iteration)
+        if self._weights is not None:
+            self._r *= self._weights
+
+        # Multiply by initial to get updated pdf
+        up_pdf = np.multiply(self._in, self._r)
         self._up = up_pdf
 
     def mud_point(self):
@@ -115,6 +142,14 @@ class BayesProblem(object):
         self._pr = None
         self._ll = None
 
+    @property
+    def _n_features(self):
+        return self.y.shape[1]
+
+    @property
+    def _n_samples(self):
+        return self.y.shape[0]
+
     def set_likelihood(self, distribution, log=False):
         if log:
             self._log = True
