@@ -10,7 +10,6 @@ __license__ = "mit"
 
 
 class TestNorm(unittest.TestCase):
-
     def test_identity_induced_norm_on_vector(self):
         # Arrange
         X = np.random.rand(2, 1)  # single vector
@@ -18,7 +17,7 @@ class TestNorm(unittest.TestCase):
 
         # Act
         result = mdn.inner_product(X, mat)
-        check = np.linalg.norm(X, axis=0)**2
+        check = np.linalg.norm(X, axis=0) ** 2
 
         # Assert
         assert isinstance(result, np.ndarray)
@@ -33,7 +32,7 @@ class TestNorm(unittest.TestCase):
 
             # Act
             result = mdn.inner_product(X, mat) * n
-            check = np.linalg.norm(X)**2
+            check = np.linalg.norm(X) ** 2
 
             # Assert
             self.assertAlmostEqual(result[0], check, 12)
@@ -51,52 +50,44 @@ class TestFunctionals_2to1(unittest.TestCase):
         self.ocov = 1
 
     def test_full_functional_with_random_input(self):
-        result = mdn.full_functional(self.operator,
-                                     self.inputs,
-                                     self.data,
-                                     self.imean,
-                                     self.icov,
-                                     self.omean,
-                                     self.ocov
-                                     )
+        result = mdn.full_functional(
+            self.operator,
+            self.inputs,
+            self.data,
+            self.imean,
+            self.icov,
+            self.omean,
+            self.ocov,
+        )
         assert result > 0
 
     def test_full_functional_with_zero_input(self):
-        result = mdn.full_functional(self.operator,
-                                     self.inputs * 0,
-                                     self.data,
-                                     self.imean,
-                                     self.icov,
-                                     self.omean,
-                                     self.ocov
-                                     )
+        result = mdn.full_functional(
+            self.operator,
+            self.inputs * 0,
+            self.data,
+            self.imean,
+            self.icov,
+            self.omean,
+            self.ocov,
+        )
         assert result == 0
 
     def test_types_of_covariance_arguments_data(self):
         for oc in [1, np.array([[1]])]:
-            result = mdn.norm_data(self.operator,
-                                   self.inputs,
-                                   self.data,
-                                   self.omean,
-                                   oc
-                                   )
+            result = mdn.norm_data(
+                self.operator, self.inputs, self.data, self.omean, oc
+            )
             assert result > 0
 
     def test_types_of_covariance_arguments_input(self):
         c = np.random.rand(self.idim, self.idim)
         for ic in [1, c @ c.T]:
-            result = mdn.norm_input(self.inputs,
-                                    self.imean,
-                                    ic
-                                    )
+            result = mdn.norm_input(self.inputs, self.imean, ic)
             assert result > 0
 
     def test_types_of_covariance_arguments_predicted(self):
         c = np.random.rand(self.idim, self.idim)
         for ic in [1, c @ c.T]:
-            result = mdn.norm_predicted(self.operator,
-                                        self.inputs,
-                                        self.imean,
-                                        ic
-                                        )
+            result = mdn.norm_predicted(self.operator, self.inputs, self.imean, ic)
             assert result > 0
